#include <detect.h>

/*----------------------------------------------------------------------*
 *	Function: BOOL E_create(detector,looksize,rectyp,detnam,dataarr,*
 *		filter) - create an event detector with given params	*
 *----------------------------------------------------------------------*
 *	Arguments:	struct detect_info *detector - calling info	*
 *			LONG looksize - lookback size for detector	*
 *				(0 if no lookback)			*
 *			LONG rectyp - record type to detect - see the	*
 *				decoder (such as E_cdsnload()) you 	*
 *				are using to find what			*
 *				numbers to use here 			*
 *			TEXT *detnam - name of detector.  Program does	*
 *				not make a copy. 			*
 *			LONG *dataarr - Pointer to the beginning of	*
 *				data array, size must be at least	*
 *				the max data point size plus the	*
 *				max lookbacks that will be encountered	*
 *			BOOL (*infilter)() - function to be used as a	*
 *				filter.  Fnull() is used if NULL spec	*
 *----------------------------------------------------------------------*
 *	Returns:	Returns TRUE if job completed sucessfully	*
 *----------------------------------------------------------------------*
 *	Creates an event detector.  Allocs memory for the lookback	*
 *	array and the continuity structure.  It then calls the		*
 *	Cont_setup() routine to initialize the continuity structure.	*
 *----------------------------------------------------------------------*/

BOOL E_create(detector,looksize,rectyp,detnam,dataarray,infilter,coefarray)
struct detect_info *detector;
LONG looksize,rectyp;
TEXT *detnam;
LONG *dataarray;
BOOL (*infilter)();
double *coefarray;
{

	ULONG msize;
	BOOL Fnull();

/*------------------------First allocate the continuity structure--------*/

	detector->incontd= (struct con_sto *) malloc(sizeof(struct con_sto));
	if (detector->incontd==NULL) return(FALSE);	/* Nope */

/*---------------Allocate the lookback storage array---------------------*/

	detector->lbkarr=NULL;		/* Initialize to no lookback */

	if (looksize>0) {
		msize=looksize;
		msize*=sizeof(LONG);

		detector->lbkarr=(LONG *) malloc(msize);

		if (detector->lbkarr==NULL) {
			free((UBYTE *) detector->incontd);
						/* Don't leave a mess */
			return(FALSE);
		}
	}

/*---------------Do all of the rest of the setup-------------------------*/

	detector->sam_sec=0;
	detector->drectyp=rectyp;
	detector->datapts=0;
	detector->indatar=dataarray;
	detector->lbksize=looksize;
	detector->detname=detnam;
	detector->filterc=infilter;
	if (infilter==NULL) detector->filterc=Fnull;
        detector->coefPtr = coefarray;
        detector->nCoef = 0;

/*---------------Call the continuity setup------------------------------*/

	Cont_setup(detector->incontd);
	detector->incontd->ch_name=detnam;

	return(TRUE);

}
